***
# Authors

**August 31, 2017**

*Copyright © Semantyk 2021. All rights reserved.*
***

## Leadership:
* Daniel Bakas Amuchástegui | Founder @ CDMX (Mexico)

## Developers:
*

## All other contributors and their affiliations:
*

## Special thanks to:
*

***